################
mididings Manual
################

mididings is a MIDI router and processor, supporting ALSA and JACK MIDI.

Homepage: http://das.nasophon.de/mididings/

The latest version of this manual can be found at
http://dsacre.github.io/mididings/doc/.


Contents:

.. toctree::
    start
    connect
    misc
    main
    units
    extra-units
    extra
    event
    engine
    util
    tools


Indices and Tables
==================

* :ref:`genindex`
* :ref:`search`
